order

package
v0.5.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	// Basic orders from the main service to the modules
	OrderStartUp     = "OrderStartUp"
	OrderError       = "OrderError"
	OrderInformation = "OrderInformation"
	OrderChange      = "OrderChange"
	OrderShutdown    = "OrderShutdown"
	OrderRender      = "OrderRender"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type MessageTo added in v0.4.1

type MessageTo struct {
	Notification string // ID to publish notification to ; should be itself
	Render       string // ID to publish render to ; should be one of the render wating routines
}

type Order

type Order struct {
	From    string // ID from who the message is. KiGo ID
	To      string // ID to who the message is. Module ID
	Order   string // what order to do, e.g. startup, update, render
	Payload any
}

type OrderChangePayload added in v0.4.0

type OrderChangePayload struct {
	Type    string
	Payload any
}

type OrderErrorPayload added in v0.4.0

type OrderErrorPayload struct {
	Message string // error message to report to the module, e.g. when a module is not responding or has an unexpected response
}

type OrderInformationPayload added in v0.4.0

type OrderInformationPayload struct {
	Payload any
}

type OrderRenderPayload

type OrderRenderPayload struct {
	ScreenWidth  int    // max screen width
	ScreenHeight int    // max screen height
	MaxFrameSize int    // max frame size
	ChannelName  string // channel name to use for transmission
	ObjectID     int    // objectID to use
}

type OrderShutdownPayload added in v0.4.1

type OrderShutdownPayload struct {
	Reason string // reason for shutdown, e.g. when the main service is shutting down, Publish to main
}

type OrderStartUpPayload

type OrderStartUpPayload struct {
	ID              string
	NumberOfModules int       // number of modules called startup ; incrementing number
	MessageTo       MessageTo // where to send the notifications and renders to
}

Jump to